Struct scratchpad::FrozenSparseMerkleTree [−][src]
pub struct FrozenSparseMerkleTree<V> { /* fields omitted */ }Expand description
In the entire lifetime of this, in-mem nodes won’t be dropped because a reference to the oldest SMT is held inside.
Implementations
Constructs a new Sparse Merkle Tree, returns the SMT root hash after each update and the
final SMT root. Since the tree is immutable, existing tree remains the same and may
share parts with the new, returned tree. Unlike serial_update', intermediate trees aren't constructed, but only root hashes are computed. batches_update’ takes value reference
because the algorithm requires a copy per value at the end of tree traversals. Taking
in a reference avoids double copy (by the caller and by the implementation).
Constructs a new Sparse Merkle Tree as if we are updating the existing tree multiple
times with the batch_update. The function will return the root hash after each
update and a Sparse Merkle Tree of the final state.
The serial_update applies batch_update' method many times, unlike a more optimized (and parallelizable) batches_update’ implementation below. It takes in a reference of
value instead of an owned instance to be consistent with the `batches_update’ interface.
pub fn generate_node_hashes(
&self,
touched_accounts: Vec<HashValue>
) -> HashMap<NibblePath, HashValue>
pub fn generate_node_hashes(
&self,
touched_accounts: Vec<HashValue>
) -> HashMap<NibblePath, HashValue>
This is a helper function that compares an updated in-memory sparse merkle with the current on-disk jellyfish sparse merkle to get the hashes of newly generated nodes.
Constructs a new Sparse Merkle Tree by applying updates, which are considered to happen
all at once. See serial_update and batches_update which take in multiple batches
of updates and yields intermediate results.
Since the tree is immutable, existing tree remains the same and may share parts with the
new, returned tree.
Queries a key in this SparseMerkleTree.